==> aiocometd-0.2.2-py3-none-any.whl: aiocometd/transports/abc.py <==
"""Transport abstract base class definition"""
from abc import ABC, abstractmethod


class Transport(ABC):
    """Defines the operations that all transport classes should support"""
    @property
    @abstractmethod
    def connection_type(self):
        """The transport's connection type"""

    @property
    @abstractmethod
    def endpoint(self):
        """CometD service url"""

    @property
    @abstractmethod
    def client_id(self):
        """Clinet id value assigned by the server"""

    @property
    @abstractmethod
    def state(self):
        """Current state of the transport"""

    @property
    @abstractmethod
    def subscriptions(self):
        """Set of subscribed channels"""

    @property
    @abstractmethod
    def last_connect_result(self):
        """Result of the last connect request"""

    @abstractmethod
    async def handshake(self, connection_types):
        """Executes the handshake operation

        :param list[ConnectionType] connection_types: list of connection types
        :return: Handshake response
        :rtype: dict
        :raises TransportError: When the network request fails.
        """

    @abstractmethod
    async def connect(self):
        """Connect to the server

        The transport will try to start and maintain a continuous connection
        with the server, but it'll return with the response of the first
        successful connection as soon as possible.

        :return dict: The response of the first successful connection.
        :raise TransportInvalidOperation: If the transport doesn't has a \
        client id yet, or if it's not in a :obj:`~TransportState.DISCONNECTED`\
        :obj:`state`.
        :raises TransportError: When the network request fails.
        """

    @abstractmethod
    async def disconnect(self):
        """Disconnect from server

        The disconnect message is only sent to the server if the transport is
        actually connected.
        """

    @abstractmethod
    async def close(self):
        """Close transport and release resources"""

    @abstractmethod
    async def subscribe(self, channel):
        """Subscribe to *channel*

        :param str channel: Name of the channel
        :return: Subscribe response
        :rtype: dict
        :raise TransportInvalidOperation: If the transport is not in the \
        :obj:`~TransportState.CONNECTED` or :obj:`~TransportState.CONNECTING` \
        :obj:`state`
        :raises TransportError: When the network request fails.
        """

    @abstractmethod
    async def unsubscribe(self, channel):
        """Unsubscribe from *channel*

        :param str channel: Name of the channel
        :return: Unsubscribe response
        :rtype: dict
        :raise TransportInvalidOperation: If the transport is not in the \
        :obj:`~TransportState.CONNECTED` or :obj:`~TransportState.CONNECTING` \
        :obj:`state`
        :raises TransportError: When the network request fails.
        """

    @abstractmethod
    async def publish(self, channel, data):
        """Publish *data* to the given *channel*

        :param str channel: Name of the channel
        :param dict data: Data to send to the server
        :return: Publish response
        :rtype: dict
        :raise TransportInvalidOperation: If the transport is not in the \
        :obj:`~TransportState.CONNECTED` or :obj:`~TransportState.CONNECTING` \
        :obj:`state`
        :raises TransportError: When the network request fails.
        """

    @abstractmethod
    async def wait_for_state(self, state):
        """Waits for and returns when the transport enters the given *state*

        :param TransportState state: A state value
        """

==> aiocometd-0.4.3-py3-none-any.whl: aiocometd/transports/abc.py <==
"""Transport abstract base class definition"""
from abc import ABC, abstractmethod
from typing import Set, Optional, List

from aiocometd.constants import ConnectionType, TransportState
from aiocometd.typing import JsonObject


class Transport(ABC):
    """Defines the operations that all transport classes should support"""
    @property
    @abstractmethod
    def connection_type(self) -> ConnectionType:
        """The transport's connection type"""

    @property
    @abstractmethod
    def endpoint(self) -> str:
        """CometD service url"""

    @property
    @abstractmethod
    def client_id(self) -> Optional[str]:
        """Clinet id value assigned by the server"""

    @property
    @abstractmethod
    def state(self) -> TransportState:
        """Current state of the transport"""

    @property
    @abstractmethod
    def subscriptions(self) -> Set[str]:
        """Set of subscribed channels"""

    @property
    @abstractmethod
    def last_connect_result(self) -> Optional[JsonObject]:
        """Result of the last connect request"""

    @property
    @abstractmethod
    def reconnect_advice(self) -> JsonObject:
        """Reconnection advice parameters returned by the server"""

    @abstractmethod
    async def handshake(self, connection_types: List[ConnectionType]) \
            -> JsonObject:
        """Executes the handshake operation

        :param connection_types: list of connection types
        :return: Handshake response
        :raises TransportError: When the network request fails.
        """

    @abstractmethod
    async def connect(self) -> JsonObject:
        """Connect to the server

        The transport will try to start and maintain a continuous connection
        with the server, but it'll return with the response of the first
        successful connection as soon as possible.

        :return: The response of the first successful connection.
        :raise TransportInvalidOperation: If the transport doesn't has a \
        client id yet, or if it's not in a :obj:`~TransportState.DISCONNECTED`\
        :obj:`state`.
        :raises TransportError: When the network request fails.
        """

    @abstractmethod
    async def disconnect(self) -> None:
        """Disconnect from server

        The disconnect message is only sent to the server if the transport is
        actually connected.
        """

    @abstractmethod
    async def close(self) -> None:
        """Close transport and release resources"""

    @abstractmethod
    async def subscribe(self, channel: str) -> JsonObject:
        """Subscribe to *channel*

        :param channel: Name of the channel
        :return: Subscribe response
        :raise TransportInvalidOperation: If the transport is not in the \
        :obj:`~TransportState.CONNECTED` or :obj:`~TransportState.CONNECTING` \
        :obj:`state`
        :raises TransportError: When the network request fails.
        """

    @abstractmethod
    async def unsubscribe(self, channel: str) -> JsonObject:
        """Unsubscribe from *channel*

        :param channel: Name of the channel
        :return: Unsubscribe response
        :raise TransportInvalidOperation: If the transport is not in the \
        :obj:`~TransportState.CONNECTED` or :obj:`~TransportState.CONNECTING` \
        :obj:`state`
        :raises TransportError: When the network request fails.
        """

    @abstractmethod
    async def publish(self, channel: str, data: JsonObject) -> JsonObject:
        """Publish *data* to the given *channel*

        :param channel: Name of the channel
        :param data: Data to send to the server
        :return: Publish response
        :raise TransportInvalidOperation: If the transport is not in the \
        :obj:`~TransportState.CONNECTED` or :obj:`~TransportState.CONNECTING` \
        :obj:`state`
        :raises TransportError: When the network request fails.
        """

    @abstractmethod
    async def wait_for_state(self, state: TransportState) -> None:
        """Waits for and returns when the transport enters the given *state*

        :param state: A state value
        """
